.. _all-salt.renderers:

==============================
Full list of builtin renderers
==============================

.. currentmodule:: salt.renderers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    salt.renderers.json_jinja
    salt.renderers.json_mako
    salt.renderers.yaml_jinja
    salt.renderers.yaml_mako
    salt.renderers.py
